#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__I__1___TwoPRep_S__0__I__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1197)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1200)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1203)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1206)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(stack[((hsi*3+1203)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1218)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*6+1206)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1228)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1231)*1+lsi)*1]), &(stack[((hsi*3+1228)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1237)*1+lsi)*1]), &(stack[((hsi*6+1231)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*3+1228)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1200)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1247)*1+lsi)*1]), &(stack[((hsi*3+1203)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1253)*1+lsi)*1]), &(stack[((hsi*6+1206)*1+lsi)*1]), &(stack[((hsi*6+1247)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(stack[((hsi*3+1203)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1263)*1+lsi)*1]), &(stack[((hsi*10+1218)*1+lsi)*1]), &(stack[((hsi*10+1253)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*6+1206)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*10+1237)*1+lsi)*1]), &(stack[((hsi*10+1218)*1+lsi)*1]), &(stack[((hsi*6+1231)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*15+1263)*1+lsi)*1]), &(stack[((hsi*10+1237)*1+lsi)*1]), &(stack[((hsi*10+1218)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1197)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1314)*1+lsi)*1]), &(stack[((hsi*6+1247)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*3+1203)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1324)*1+lsi)*1]), &(stack[((hsi*10+1253)*1+lsi)*1]), &(stack[((hsi*10+1314)*1+lsi)*1]), &(stack[((hsi*6+1206)*1+lsi)*1]), &(stack[((hsi*6+1247)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1339)*1+lsi)*1]), &(stack[((hsi*15+1263)*1+lsi)*1]), &(stack[((hsi*15+1324)*1+lsi)*1]), &(stack[((hsi*10+1218)*1+lsi)*1]), &(stack[((hsi*10+1253)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1360)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*21+1339)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*15+1263)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1218)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1203)*1+lsi)*1]), &(stack[((hsi*3+1218)*1+lsi)*1]), &(stack[((hsi*3+1228)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1388)*1+lsi)*1]), &(stack[((hsi*6+1203)*1+lsi)*1]), &(stack[((hsi*6+1231)*1+lsi)*1]), &(stack[((hsi*3+1218)*1+lsi)*1]), &(stack[((hsi*3+1228)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1398)*1+lsi)*1]), &(stack[((hsi*10+1388)*1+lsi)*1]), &(stack[((hsi*10+1237)*1+lsi)*1]), &(stack[((hsi*6+1203)*1+lsi)*1]), &(stack[((hsi*6+1231)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1413)*1+lsi)*1]), &(stack[((hsi*15+1398)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*10+1388)*1+lsi)*1]), &(stack[((hsi*10+1237)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1218)*1+lsi)*1]), &(stack[((hsi*21+1413)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*15+1398)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*84+1434)*1+lsi)*1]), &(stack[((hsi*28+1218)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*84+0)*1+lsi)*1]),&(stack[((hsi*84+1434)*1+lsi)*1]),84);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1388)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1391)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(stack[((hsi*3+1388)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1397)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*6+1391)*1+lsi)*1]), &(stack[((hsi*3+1200)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*10+1314)*1+lsi)*1]), &(stack[((hsi*10+1397)*1+lsi)*1]), &(stack[((hsi*6+1247)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1518)*1+lsi)*1]), &(stack[((hsi*15+1324)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*10+1253)*1+lsi)*1]), &(stack[((hsi*10+1314)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1539)*1+lsi)*1]), &(stack[((hsi*21+1339)*1+lsi)*1]), &(stack[((hsi*21+1518)*1+lsi)*1]), &(stack[((hsi*15+1263)*1+lsi)*1]), &(stack[((hsi*15+1324)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1567)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]), &(stack[((hsi*28+1539)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*21+1339)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1603)*1+lsi)*1]), &(stack[((hsi*28+1218)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]), &(stack[((hsi*21+1413)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1639)*1+lsi)*1]), &(stack[((hsi*36+1603)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+84)*1+lsi)*1]),&(stack[((hsi*108+1639)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1246)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1249)*1+lsi)*1]), &(stack[((hsi*3+1388)*1+lsi)*1]), &(stack[((hsi*3+1246)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1407)*1+lsi)*1]), &(stack[((hsi*6+1391)*1+lsi)*1]), &(stack[((hsi*6+1249)*1+lsi)*1]), &(stack[((hsi*3+1197)*1+lsi)*1]), &(stack[((hsi*3+1388)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1197)*1+lsi)*1]), &(stack[((hsi*10+1397)*1+lsi)*1]), &(stack[((hsi*10+1407)*1+lsi)*1]), &(stack[((hsi*6+1212)*1+lsi)*1]), &(stack[((hsi*6+1391)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*15+1197)*1+lsi)*1]), &(stack[((hsi*10+1314)*1+lsi)*1]), &(stack[((hsi*10+1397)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1747)*1+lsi)*1]), &(stack[((hsi*21+1518)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*15+1324)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1775)*1+lsi)*1]), &(stack[((hsi*28+1539)*1+lsi)*1]), &(stack[((hsi*28+1747)*1+lsi)*1]), &(stack[((hsi*21+1339)*1+lsi)*1]), &(stack[((hsi*21+1518)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1314)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]), &(stack[((hsi*36+1775)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]), &(stack[((hsi*28+1539)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1811)*1+lsi)*1]), &(stack[((hsi*36+1603)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]), &(stack[((hsi*28+1218)*1+lsi)*1]), &(stack[((hsi*28+1360)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1856)*1+lsi)*1]), &(stack[((hsi*45+1811)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+192)*1+lsi)*1]),&(stack[((hsi*135+1856)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1212)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1215)*1+lsi)*1]), &(stack[((hsi*3+1246)*1+lsi)*1]), &(stack[((hsi*3+1212)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1359)*1+lsi)*1]), &(stack[((hsi*6+1249)*1+lsi)*1]), &(stack[((hsi*6+1215)*1+lsi)*1]), &(stack[((hsi*3+1388)*1+lsi)*1]), &(stack[((hsi*3+1246)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1221)*1+lsi)*1]), &(stack[((hsi*10+1407)*1+lsi)*1]), &(stack[((hsi*10+1359)*1+lsi)*1]), &(stack[((hsi*6+1391)*1+lsi)*1]), &(stack[((hsi*6+1249)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1369)*1+lsi)*1]), &(stack[((hsi*15+1197)*1+lsi)*1]), &(stack[((hsi*15+1221)*1+lsi)*1]), &(stack[((hsi*10+1397)*1+lsi)*1]), &(stack[((hsi*10+1407)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1991)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*21+1369)*1+lsi)*1]), &(stack[((hsi*15+1278)*1+lsi)*1]), &(stack[((hsi*15+1197)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1255)*1+lsi)*1]), &(stack[((hsi*28+1747)*1+lsi)*1]), &(stack[((hsi*28+1991)*1+lsi)*1]), &(stack[((hsi*21+1518)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2019)*1+lsi)*1]), &(stack[((hsi*36+1775)*1+lsi)*1]), &(stack[((hsi*36+1255)*1+lsi)*1]), &(stack[((hsi*28+1539)*1+lsi)*1]), &(stack[((hsi*28+1747)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2064)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]), &(stack[((hsi*45+2019)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]), &(stack[((hsi*36+1775)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2119)*1+lsi)*1]), &(stack[((hsi*45+1811)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]), &(stack[((hsi*36+1603)*1+lsi)*1]), &(stack[((hsi*36+1567)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+2174)*1+lsi)*1]), &(stack[((hsi*55+2119)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+327)*1+lsi)*1]),&(stack[((hsi*165+2174)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1518)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1521)*1+lsi)*1]), &(stack[((hsi*3+1212)*1+lsi)*1]), &(stack[((hsi*3+1518)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1236)*1+lsi)*1]), &(stack[((hsi*6+1215)*1+lsi)*1]), &(stack[((hsi*6+1521)*1+lsi)*1]), &(stack[((hsi*3+1246)*1+lsi)*1]), &(stack[((hsi*3+1212)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1527)*1+lsi)*1]), &(stack[((hsi*10+1359)*1+lsi)*1]), &(stack[((hsi*10+1236)*1+lsi)*1]), &(stack[((hsi*6+1249)*1+lsi)*1]), &(stack[((hsi*6+1215)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1542)*1+lsi)*1]), &(stack[((hsi*15+1221)*1+lsi)*1]), &(stack[((hsi*15+1527)*1+lsi)*1]), &(stack[((hsi*10+1407)*1+lsi)*1]), &(stack[((hsi*10+1359)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1563)*1+lsi)*1]), &(stack[((hsi*21+1369)*1+lsi)*1]), &(stack[((hsi*21+1542)*1+lsi)*1]), &(stack[((hsi*15+1197)*1+lsi)*1]), &(stack[((hsi*15+1221)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1591)*1+lsi)*1]), &(stack[((hsi*28+1991)*1+lsi)*1]), &(stack[((hsi*28+1563)*1+lsi)*1]), &(stack[((hsi*21+1293)*1+lsi)*1]), &(stack[((hsi*21+1369)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+2339)*1+lsi)*1]), &(stack[((hsi*36+1255)*1+lsi)*1]), &(stack[((hsi*36+1591)*1+lsi)*1]), &(stack[((hsi*28+1747)*1+lsi)*1]), &(stack[((hsi*28+1991)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+2384)*1+lsi)*1]), &(stack[((hsi*45+2019)*1+lsi)*1]), &(stack[((hsi*45+2339)*1+lsi)*1]), &(stack[((hsi*36+1775)*1+lsi)*1]), &(stack[((hsi*36+1255)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2439)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]), &(stack[((hsi*55+2384)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]), &(stack[((hsi*45+2019)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2505)*1+lsi)*1]), &(stack[((hsi*55+2119)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]), &(stack[((hsi*45+1811)*1+lsi)*1]), &(stack[((hsi*45+1314)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+2571)*1+lsi)*1]), &(stack[((hsi*66+2505)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+492)*1+lsi)*1]),&(stack[((hsi*198+2571)*1+lsi)*1]),198);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1747)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1750)*1+lsi)*1]), &(stack[((hsi*3+1518)*1+lsi)*1]), &(stack[((hsi*3+1747)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1756)*1+lsi)*1]), &(stack[((hsi*6+1521)*1+lsi)*1]), &(stack[((hsi*6+1750)*1+lsi)*1]), &(stack[((hsi*3+1212)*1+lsi)*1]), &(stack[((hsi*3+1518)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1766)*1+lsi)*1]), &(stack[((hsi*10+1236)*1+lsi)*1]), &(stack[((hsi*10+1756)*1+lsi)*1]), &(stack[((hsi*6+1215)*1+lsi)*1]), &(stack[((hsi*6+1521)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1781)*1+lsi)*1]), &(stack[((hsi*15+1527)*1+lsi)*1]), &(stack[((hsi*15+1766)*1+lsi)*1]), &(stack[((hsi*10+1359)*1+lsi)*1]), &(stack[((hsi*10+1236)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1291)*1+lsi)*1]), &(stack[((hsi*21+1542)*1+lsi)*1]), &(stack[((hsi*21+1781)*1+lsi)*1]), &(stack[((hsi*15+1221)*1+lsi)*1]), &(stack[((hsi*15+1527)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1802)*1+lsi)*1]), &(stack[((hsi*28+1563)*1+lsi)*1]), &(stack[((hsi*28+1291)*1+lsi)*1]), &(stack[((hsi*21+1369)*1+lsi)*1]), &(stack[((hsi*21+1542)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1319)*1+lsi)*1]), &(stack[((hsi*36+1591)*1+lsi)*1]), &(stack[((hsi*36+1802)*1+lsi)*1]), &(stack[((hsi*28+1991)*1+lsi)*1]), &(stack[((hsi*28+1563)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1364)*1+lsi)*1]), &(stack[((hsi*45+2339)*1+lsi)*1]), &(stack[((hsi*45+1319)*1+lsi)*1]), &(stack[((hsi*36+1255)*1+lsi)*1]), &(stack[((hsi*36+1591)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+2769)*1+lsi)*1]), &(stack[((hsi*55+2384)*1+lsi)*1]), &(stack[((hsi*55+1364)*1+lsi)*1]), &(stack[((hsi*45+2019)*1+lsi)*1]), &(stack[((hsi*45+2339)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2835)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]), &(stack[((hsi*66+2769)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]), &(stack[((hsi*55+2384)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+2913)*1+lsi)*1]), &(stack[((hsi*66+2505)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]), &(stack[((hsi*55+2119)*1+lsi)*1]), &(stack[((hsi*55+2064)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*234+2991)*1+lsi)*1]), &(stack[((hsi*78+2913)*1+lsi)*1]), &(stack[((hsi*78+2835)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*234+690)*1+lsi)*1]),&(stack[((hsi*234+2991)*1+lsi)*1]),234);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1991)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_13[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1994)*1+lsi)*1]), &(stack[((hsi*3+1747)*1+lsi)*1]), &(stack[((hsi*3+1991)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_12[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+2000)*1+lsi)*1]), &(stack[((hsi*6+1750)*1+lsi)*1]), &(stack[((hsi*6+1994)*1+lsi)*1]), &(stack[((hsi*3+1518)*1+lsi)*1]), &(stack[((hsi*3+1747)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1419)*1+lsi)*1]), &(stack[((hsi*10+1756)*1+lsi)*1]), &(stack[((hsi*10+2000)*1+lsi)*1]), &(stack[((hsi*6+1521)*1+lsi)*1]), &(stack[((hsi*6+1750)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1991)*1+lsi)*1]), &(stack[((hsi*15+1766)*1+lsi)*1]), &(stack[((hsi*15+1419)*1+lsi)*1]), &(stack[((hsi*10+1236)*1+lsi)*1]), &(stack[((hsi*10+1756)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+2012)*1+lsi)*1]), &(stack[((hsi*21+1781)*1+lsi)*1]), &(stack[((hsi*21+1991)*1+lsi)*1]), &(stack[((hsi*15+1527)*1+lsi)*1]), &(stack[((hsi*15+1766)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+2040)*1+lsi)*1]), &(stack[((hsi*28+1291)*1+lsi)*1]), &(stack[((hsi*28+2012)*1+lsi)*1]), &(stack[((hsi*21+1542)*1+lsi)*1]), &(stack[((hsi*21+1781)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1518)*1+lsi)*1]), &(stack[((hsi*36+1802)*1+lsi)*1]), &(stack[((hsi*36+2040)*1+lsi)*1]), &(stack[((hsi*28+1563)*1+lsi)*1]), &(stack[((hsi*28+1291)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1747)*1+lsi)*1]), &(stack[((hsi*45+1319)*1+lsi)*1]), &(stack[((hsi*45+1518)*1+lsi)*1]), &(stack[((hsi*36+1591)*1+lsi)*1]), &(stack[((hsi*36+1802)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1991)*1+lsi)*1]), &(stack[((hsi*55+1364)*1+lsi)*1]), &(stack[((hsi*55+1747)*1+lsi)*1]), &(stack[((hsi*45+2339)*1+lsi)*1]), &(stack[((hsi*45+1319)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pp__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*78+1197)*1+lsi)*1]), &(stack[((hsi*66+2769)*1+lsi)*1]), &(stack[((hsi*66+1991)*1+lsi)*1]), &(stack[((hsi*55+2384)*1+lsi)*1]), &(stack[((hsi*55+1364)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1991)*1+lsi)*1]), &(stack[((hsi*78+2835)*1+lsi)*1]), &(stack[((hsi*78+1197)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]), &(stack[((hsi*66+2769)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*91+1197)*1+lsi)*1]), &(stack[((hsi*78+2913)*1+lsi)*1]), &(stack[((hsi*78+2835)*1+lsi)*1]), &(stack[((hsi*66+2505)*1+lsi)*1]), &(stack[((hsi*66+2439)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__pd__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*273+3225)*1+lsi)*1]), &(stack[((hsi*91+1197)*1+lsi)*1]), &(stack[((hsi*91+1991)*1+lsi)*1]), &(stack[((hsi*78+2835)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*273+924)*1+lsi)*1]),&(stack[((hsi*273+3225)*1+lsi)*1]),273);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 1197 */
}

#ifdef __cplusplus
};
#endif
